#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <cmqc.h>
#include <time.h>

#define NUM_MESSAGES 1
#define IN
#define OUT

#define XML_MESSAGE \
"<outer>"\
     "<tag1>data1</tag1>"\
"</outer>"


#define PUT_Q "I1.Q"
#define GET_Q "SQLCODE_42704.Q"

#if defined(WIN32)
    #define QM_DEFAULT "MQSI_QM"
#elif defined(_AIX)
    #define QM_DEFAULT "SEAIX_QM"
#elif defined(_SOLARIS)
    #define QM_DEFAULT "SUN_QM"
#elif defined(_HPUX)
    #define QM_DEFAULT "HP_QM"
#endif

void dispHex(IN char *inputString, 
			 IN int inputStringlength, 
			 OUT char *hexString);

int main(int argc, char *argv[])
{
	MQHCONN hConn;
	MQHOBJ putHandle, 
		   getHandle;
    MQLONG   openOptions;               /* MQOPEN options                */
    MQOD od = {MQOD_DEFAULT};           /* Object Descriptor */
    MQPMO pmo = {MQPMO_DEFAULT};        /* put message options */
    MQGMO gmo = {MQGMO_DEFAULT};        /* put message options */
	MQMD md,
		 mdDefault = {MQMD_DEFAULT};           /* Message Descriptor */
	MQLONG compCode,
		   reason;
	int msgFlow2 = 0;
	int messageLength,
		returnedMessageLength;
	char message[10000],
		 *qmName,
		 *putQueue,
		 *getQueue;

	/* display usage template if requested */
    if (argc == 2 && argv[1][0] == '?' ||
        argc > 1 && argc != 4)
	{
		printf("Usage: %s < <queueManagerName> <PUT Queue> <GET Queue> >\n",
			    argv[0]);
		return(0);
	}

    if (argc > 1)
    {
        /* read in queue manager name */
		qmName = argv[1];

		/* now read the queue name(s) */
		putQueue = argv[2];
		getQueue = argv[3];
    }
    else
    {
		qmName = QM_DEFAULT;
		putQueue = PUT_Q;
		getQueue = GET_Q;
    }

	printf("Queue manager: %s\n", qmName);
	printf("PUT queue: %s\n", putQueue);
	printf("GET queue: %s\n", getQueue);

	/* connect to queue manager, assume default */
	MQCONN(qmName,
		   &hConn,
		   &compCode,
		   &reason);
	if (reason != MQRC_NONE)
	{
		printf("MQCONN failed with compcode=%d, reason=%d\n",
			   compCode, reason);
		exit(1);
	}

	/* open the PUT queue */
	strcpy(od.ObjectName, putQueue);
	openOptions = MQOO_OUTPUT + MQOO_FAIL_IF_QUIESCING; /* open queue for output */

	MQOPEN(hConn,
		   &od,
		   openOptions,
		   &putHandle,
		   &compCode,
		   &reason);
	if (reason != MQRC_NONE)
	{
		printf("MQOPEN for PUT queue '%s' failed with compcode=%d, reason=%d\n",
			   od.ObjectName, compCode, reason);
		exit(1);
	}

	/* open the GET queue */
	strcpy(od.ObjectName, getQueue);
	openOptions = MQOO_INPUT_AS_Q_DEF + MQOO_FAIL_IF_QUIESCING; /* open queue for output */

	MQOPEN(hConn,
		   &od,
		   openOptions,
		   &getHandle,
		   &compCode,
		   &reason);
	if (reason != MQRC_NONE)
	{
		printf("MQOPEN for GET queue '%s' failed with compcode=%d, reason=%d\n",
			   od.ObjectName, compCode, reason);
		exit(1);
	}

	/* build BLOB type message or XML message */
#if 0
	sprintf(message, "This is a BLOB message");
#else
	strcpy(message, XML_MESSAGE);
#endif
	printf("Putting request message '%s' on queue %s\n",
			message, putQueue);
	messageLength = strlen(message);
	memcpy(&md, &mdDefault, sizeof(md));

	/* put the message on the queue */
	MQPUT(hConn,                   /* connection handle */
		  putHandle,               /* object handle */
		  &md,                     /* message descriptor */
		  &pmo,                    /* put options */
		  (MQLONG)messageLength,   /* msg length */
		  message,                 /* message buffer */
		  &compCode,               /* completion code */
		  &reason);                /* reason code */
	if (reason != MQRC_NONE)
	{
		printf("MQPUT failed with compcode=%d, reason=%d\n",
			   compCode, reason);
		exit(1);
	}

	/* read the modified message from the GET queue */
	fprintf(stderr, "about to modified message from queue %s\n", getQueue);
	messageLength = sizeof(message);
	memcpy(&md, &mdDefault, sizeof(md));

	gmo.Options = MQGMO_WAIT +
		          MQGMO_NO_SYNCPOINT;
    gmo.WaitInterval = MQWI_UNLIMITED;

	/* get the message from the queue */
	MQGET(hConn,                   /* connection handle */
		  getHandle,               /* object handle */
		  &md,                     /* message descriptor */
		  &gmo,                    /* put options */
		  (MQLONG)messageLength,   /* msg length */
		  message,                 /* message buffer */
  (long *)&returnedMessageLength,  /* returned message length */
		  &compCode,               /* completion code */
		  &reason);                /* reason code */
	if (reason != MQRC_NONE)
	{
		printf("MQGET failed with compcode=%d, reason=%d\n",
			   compCode, reason);
		exit(1);
	}

	fprintf(stderr, "Modified message is:\n'%.*s'\n",
			        returnedMessageLength, message);

	MQDISC(&hConn,
		   &compCode,
		   &reason);
	if (reason != MQRC_NONE)
	{
		printf("MQDISC failed with compcode=%d, reason=%d\n",
			   compCode, reason);
		exit(1);
	}

    return(0);
}

void dispHex(IN char *inputString, 
			 IN int inputStringlength, 
			 OUT char *hexString)
{

	int i;
	char tempBuf[10];
    unsigned char *ch; 				        /* Current Buffer position */

    ch = (unsigned char *)inputString;

	/* start with null-terminated string */
	*hexString = '\0';

	for (i=0; i<inputStringlength; i++)
	{
		sprintf(tempBuf, "%0.2x", *ch++);
		strcat(hexString, tempBuf);
	}
    return;
}

