#if !defined(__GETSQLCODE_CONSTANTS_H)
    #define __GETSQLCODE_CONSTANTS_H
/******************************************************************************/
/*                                                                            */
/* Licensed Materials - Property of IBM                                       */
/* (C) Copyright IBM Corp. 2000                                               */
/*                                                                            */
/* Program name    : getSQLCode_constants.h                                   */
/*                                                                            */
/* Description     : This header file contains unicode constants for the      */
/*                   getSQLCode plug-in node.                                 */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Version 1.0                                                                */
/* Author: Mike Brady                      Date: Jul 2001                     */
/*                                                                            */
/******************************************************************************/

#include <BipCci.h>	  /* Data types for Plug-in Node functions     */

#if defined(WIN32)  // little endian, so no need to shift bytes 
	#define UC(__char) ((CciChar)__char)
	#define UCB ((CciChar)' ')
	#define UCDOT ((CciChar)'.')
#elif defined(_SOLARIS) || defined(_HPUX)
	#define UC(__char) (((CciChar)__char))
	#define UCB (((CciChar)' '))
	#define UCDOT (((CciChar)'.'))
#else
	#define UC(__char) (((CciChar)__char)<<8)
	#define UCB (((CciChar)' ')<<8)
	#define UCDOT (((CciChar)'.')<<8)
#endif

typedef struct getSQLCodeConstants {
    CciChar 
        *PLUGIN_MESSAGE_CATALOGUE,
        *GET_SQL_CODE_NODE,
        *ATTR_COPY_VALUE_TO,
        *ATTR_INCLUDE_SEPARATORS,
        *ATTR_INCLUDE_SEPARATORS_DEFAULT_VALUE,
        *ATTR_LABEL,
        *ATTR_USER_TRACE_LEVEL,
        *ATTR_TRACE_LEVEL,
        *ATTR_USER_TRACE_FILTER,
        *ATTR_TRACE_FILTER,
        *TERM_IN,
        *TERM_OUT,
        *TERM_FAILURE,
        *TERM_NOT_FOUND,
        *ROOT,
        *ROOT_DOT,
        *ENVIRONMENT,
        *BLOB,
        *NONE,
        *ROOT_DOT_MQMD_DOT,
        *ROOT_DOT_PROPERTIES_DOT,
        *ROOT_DOT_XML,
        *ROOT_DOT_XML_DOT,
        *XML,
        *FORMAT,
        *NULL_STRING,
        *NULL_LITERAL,
        *TRUE_C,
        *FALSE_C,
        *DESTINATION,
        *MQ_DESTINATION_LIST,
        *DESTINATION_DATA,
        *DATABASE_EXCEPTION,
        *INSERT,
        *TEXT,
        *SQLSTATE,
        *SQLSTATE_EQUALS,
        *MQMD,
        *MSG_ID,
        *CORREL_ID,
        *PUT_APPL_NAME,
        *REPLY_TO_Q,
        *REPLY_TO_Q_MGR,
        *QUEUE_MANAGER_NAME,
        *QUEUE_NAME,
        *ALL_NUMBERS,
        *GETSQLCODE_PLUGIN_FACTORY,
        DOT_CHAR,
        BLANK_CHAR;
} getSQLCodeConstants_t;

/* build static initialisation values for Solaris */
#if defined(_SOLARIS) || defined(_HPUX)

#if defined(GLOBAL_GETSQLCODE_DATA)
CciChar 
    PLUGIN_MESSAGE_CATALOGUE_VAL[sizeof("MQSIV2_getSQLCode")*sizeof(CciChar)] =
    {'M','Q','S','I','V','2','_','g','e','t','S','Q','L','C','o','d','e',0},
    GET_SQL_CODE_NODE_VAL[sizeof("GetSQLCodeNode")*sizeof(CciChar)] =
    {'G','e','t','S','Q','L','C','o','d','e','N','o','d','e',0},
    ATTR_COPY_VALUE_TO_VAL[sizeof("CopyValueTo")*sizeof(CciChar)] =
    {'C','o','p','y','V','a','l','u','e','T','o',0},
    ATTR_INCLUDE_SEPARATORS_VAL[sizeof("IncludeSeparators")*sizeof(CciChar)] =
    {'I','n','c','l','u','d','e','S','e','p','a','r','a','t','o','r','s',0},
    ATTR_INCLUDE_SEPARATORS_DEFAULT_VALUE_VAL[sizeof("false")*sizeof(CciChar)] =
    {'f','a','l','s','e',0},
    ATTR_LABEL_VAL[sizeof("label")*sizeof(CciChar)] =
    {'l','a','b','e','l',0},
    ATTR_USER_TRACE_LEVEL_VAL[sizeof("userTraceLevel")*sizeof(CciChar)] =
    {'u','s','e','r','T','r','a','c','e','L','e','v','e','l',0},
    ATTR_TRACE_LEVEL_VAL[sizeof("traceLevel")*sizeof(CciChar)] =
    {'t','r','a','c','e','L','e','v','e','l',0},
    ATTR_USER_TRACE_FILTER_VAL[sizeof("userTraceFilter")*sizeof(CciChar)] =
    {'u','s','e','r','T','r','a','c','e','F','i','l','t','e','r',0},
    ATTR_TRACE_FILTER_VAL[sizeof("traceFilter")*sizeof(CciChar)] =
    {'t','r','a','c','e','F','i','l','t','e','r',0},
    TERM_IN_VAL[sizeof("in")*sizeof(CciChar)] =
    {'i','n',0},
    TERM_OUT_VAL[sizeof("out")*sizeof(CciChar)] =
    {'o','u','t',0},
    TERM_FAILURE_VAL[sizeof("failure")*sizeof(CciChar)] =
    {'f','a','i','l','u','r','e',0},
    TERM_NOT_FOUND_VAL[sizeof("notFound")*sizeof(CciChar)] =
    {'n','o','t','F','o','u','n','d',0},
    ROOT_VAL[sizeof("Root")*sizeof(CciChar)] =
    {'R','o','o','t',0},
    ROOT_DOT_VAL[sizeof("Root.")*sizeof(CciChar)] =
    {'R','o','o','t','.',0},
    ENVIRONMENT_VAL[sizeof("Environment")*sizeof(CciChar)] =
    {'E','n','v','i','r','o','n','m','e','n','t',0},
    BLOB_VAL[sizeof("BLOB")*sizeof(CciChar)] =
    {'B','L','O','B',0},
    NONE_VAL[sizeof("none")*sizeof(CciChar)] =
    {'n','o','n','e',0},
    ROOT_DOT_MQMD_DOT_VAL[sizeof("Root.MQMD.")*sizeof(CciChar)] =
    {'R','o','o','t','.','M','Q','M','D','.',0},
    ROOT_DOT_PROPERTIES_DOT_VAL[sizeof("Root.Properties.")*sizeof(CciChar)] =
    {'R','o','o','t','.','P','r','o','p','e','r','t','i','e','s','.',0},
    ROOT_DOT_XML_VAL[sizeof("Root.XML")*sizeof(CciChar)] =
    {'R','o','o','t','.','X','M','L',0},
    ROOT_DOT_XML_DOT_VAL[sizeof("Root.XML.")*sizeof(CciChar)] =
    {'R','o','o','t','.','X','M','L','.',0},
    XML_VAL[sizeof("XML")*sizeof(CciChar)] =
    {'X','M','L',0},
    FORMAT_VAL[sizeof("Format")*sizeof(CciChar)] =
    {'F','o','r','m','a','t',0},
    NULL_STRING_VAL[sizeof("")*sizeof(CciChar)] =
    {0},
    NULL_LITERAL_VAL[sizeof("null")*sizeof(CciChar)] =
    {'n','u','l','l',0},
    TRUE_C_VAL[sizeof("true")*sizeof(CciChar)] =
    {'t','r','u','e',0},
    FALSE_C_VAL[sizeof("false")*sizeof(CciChar)] =
    {'f','a','l','s','e',0},
    DESTINATION_VAL[sizeof("Destination")*sizeof(CciChar)] =
    {'D','e','s','t','i','n','a','t','i','o','n',0},
    MQ_DESTINATION_LIST_VAL[sizeof("MQDestinationList")*sizeof(CciChar)] =
    {'M','Q','D','e','s','t','i','n','a','t','i','o','n','L','i','s','t',0},
    DESTINATION_DATA_VAL[sizeof("DestinationData")*sizeof(CciChar)] =
    {'D','e','s','t','i','n','a','t','i','o','n','D','a','t','a',0},
    DATABASE_EXCEPTION_VAL[sizeof("DatabaseException")*sizeof(CciChar)] =
    {'D','a','t','a','b','a','s','e','E','x','c','e','p','t','i','o','n',0},
    INSERT_VAL[sizeof("Insert")*sizeof(CciChar)] =
    {'I','n','s','e','r','t',0},
    TEXT_VAL[sizeof("Text")*sizeof(CciChar)] =
    {'T','e','x','t',0},
    SQLSTATE_VAL[sizeof("SQLSTATE")*sizeof(CciChar)] =
    {'S','Q','L','S','T','A','T','E',0},
    SQLSTATE_EQUALS_VAL[sizeof("SQLSTATE=")*sizeof(CciChar)] =
    {'S','Q','L','S','T','A','T','E','=',0},
    MQMD_VAL[sizeof("MQMD")*sizeof(CciChar)] =
    {'M','Q','M','D',0},
    MSG_ID_VAL[sizeof("MsgId")*sizeof(CciChar)] =
    {'M','s','g','I','d',0},
    CORREL_ID_VAL[sizeof("CorrelId")*sizeof(CciChar)] =
    {'C','o','r','r','e','l','I','d',0},
    PUT_APPL_NAME_VAL[sizeof("PutApplName")*sizeof(CciChar)] =
    {'P','u','t','A','p','p','l','N','a','m','e',0},
    REPLY_TO_Q_VAL[sizeof("ReplyToQ")*sizeof(CciChar)] =
    {'R','e','p','l','y','T','o','Q',0},
    REPLY_TO_Q_MGR_VAL[sizeof("ReplyToQMgr")*sizeof(CciChar)] =
    {'R','e','p','l','y','T','o','Q','M','g','r',0},
    QUEUE_MANAGER_NAME_VAL[sizeof("queueManagerName")*sizeof(CciChar)] =
    {'q','u','e','u','e','M','a','n','a','g','e','r','N','a','m','e',0},
    QUEUE_NAME_VAL[sizeof("queueName")*sizeof(CciChar)] =
    {'q','u','e','u','e','N','a','m','e',0},
    ALL_NUMBERS_VAL[sizeof("0123456789")*sizeof(CciChar)] =
    {'0','1','2','3','4','5','6','7','8','9',0},
    GETSQLCODE_PLUGIN_FACTORY_VAL[sizeof("GetSQLCodePlugInFactory")*sizeof(CciChar)] =
    {'G','e','t','S','Q','L','C','o','d','e','P','l','u','g','I','n','F','a','c','t','o','r','y',0};
#else
extern CciChar 
    PLUGIN_MESSAGE_CATALOGUE_VAL[],
    GET_SQL_CODE_NODE_VAL[],
    ATTR_COPY_VALUE_TO_VAL[],
    ATTR_INCLUDE_SEPARATORS_VAL[],
    ATTR_INCLUDE_SEPARATORS_DEFAULT_VALUE_VAL[],
    ATTR_LABEL_VAL[],
    ATTR_USER_TRACE_LEVEL_VAL[],
    ATTR_TRACE_LEVEL_VAL[],
    ATTR_USER_TRACE_FILTER_VAL[],
    ATTR_TRACE_FILTER_VAL[],
    TERM_IN_VAL[],
    TERM_OUT_VAL[],
    TERM_FAILURE_VAL[],
    TERM_NOT_FOUND_VAL[],
    ROOT_VAL[],
    ROOT_DOT_VAL[],
    ENVIRONMENT_VAL[],
    BLOB_VAL[],
    NONE_VAL[],
    ROOT_DOT_MQMD_DOT_VAL[],
    ROOT_DOT_PROPERTIES_DOT_VAL[],
    ROOT_DOT_XML_VAL[],
    ROOT_DOT_XML_DOT_VAL[],
    XML_VAL[],
    FORMAT_VAL[],
    NULL_STRING_VAL[],
    NULL_LITERAL_VAL[],
    TRUE_C_VAL[],
    FALSE_C_VAL[],
    DESTINATION_VAL[],
    MQ_DESTINATION_LIST_VAL[],
    DESTINATION_DATA_VAL[],
    DATABASE_EXCEPTION_VAL[],
    INSERT_VAL[],
    TEXT_VAL[],
    SQLSTATE_VAL[],
    SQLSTATE_EQUALS_VAL[],
    MQMD_VAL[],
    MSG_ID_VAL[],
    CORREL_ID_VAL[],
    PUT_APPL_NAME_VAL[],
    REPLY_TO_Q_VAL[],
    REPLY_TO_Q_MGR_VAL[],
    QUEUE_MANAGER_NAME_VAL[],
    QUEUE_NAME_VAL[],
    ALL_NUMBERS_VAL[],
    GETSQLCODE_PLUGIN_FACTORY_VAL[];
#endif
#endif


/* define the initialisation macro */
#if defined(WIN32) || defined(_AIX)
#define GETSQLCODE_CONSTANTS_DEFAULTS \
    L"MQSIV2_getSQLCode", \
    L"GetSQLCodeNode", \
    L"CopyValueTo", \
    L"IncludeSeparators", \
    L"false", \
    L"label", \
    L"userTraceLevel", \
    L"traceLevel", \
    L"userTraceFilter", \
    L"traceFilter", \
    L"in", \
    L"out", \
    L"failure", \
    L"notFound", \
    L"Root", \
    L"Root.", \
    L"Environment", \
    L"BLOB", \
    L"none", \
    L"Root.MQMD.", \
    L"Root.Properties.", \
    L"Root.XML", \
    L"Root.XML.", \
    L"XML", \
    L"Format", \
    L"", \
    L"null", \
    L"true", \
    L"false", \
    L"Destination", \
    L"MQDestinationList", \
    L"DestinationData", \
    L"DatabaseException", \
    L"Insert", \
    L"Text", \
    L"SQLSTATE", \
    L"SQLSTATE=", \
    L"MQMD", \
    L"MsgId", \
    L"CorrelId", \
    L"PutApplName", \
    L"ReplyToQ", \
    L"ReplyToQMgr", \
    L"queueManagerName", \
    L"queueName", \
    L"0123456789", \
    L"GetSQLCodePlugInFactory", \
    L'.', \
    L' '


#elif defined(_SOLARIS) || defined(_HPUX)

#define GETSQLCODE_CONSTANTS_DEFAULTS \
    PLUGIN_MESSAGE_CATALOGUE_VAL, \
    GET_SQL_CODE_NODE_VAL, \
    ATTR_COPY_VALUE_TO_VAL, \
    ATTR_INCLUDE_SEPARATORS_VAL, \
    ATTR_INCLUDE_SEPARATORS_DEFAULT_VALUE_VAL, \
    ATTR_LABEL_VAL, \
    ATTR_USER_TRACE_LEVEL_VAL, \
    ATTR_TRACE_LEVEL_VAL, \
    ATTR_USER_TRACE_FILTER_VAL, \
    ATTR_TRACE_FILTER_VAL, \
    TERM_IN_VAL, \
    TERM_OUT_VAL, \
    TERM_FAILURE_VAL, \
    TERM_NOT_FOUND_VAL, \
    ROOT_VAL, \
    ROOT_DOT_VAL, \
    ENVIRONMENT_VAL, \
    BLOB_VAL, \
    NONE_VAL, \
    ROOT_DOT_MQMD_DOT_VAL, \
    ROOT_DOT_PROPERTIES_DOT_VAL, \
    ROOT_DOT_XML_VAL, \
    ROOT_DOT_XML_DOT_VAL, \
    XML_VAL, \
    FORMAT_VAL, \
    NULL_STRING_VAL, \
    NULL_LITERAL_VAL, \
    TRUE_C_VAL, \
    FALSE_C_VAL, \
    DESTINATION_VAL, \
    MQ_DESTINATION_LIST_VAL, \
    DESTINATION_DATA_VAL, \
    DATABASE_EXCEPTION_VAL, \
    INSERT_VAL, \
    TEXT_VAL, \
    SQLSTATE_VAL, \
    SQLSTATE_EQUALS_VAL, \
    MQMD_VAL, \
    MSG_ID_VAL, \
    CORREL_ID_VAL, \
    PUT_APPL_NAME_VAL, \
    REPLY_TO_Q_VAL, \
    REPLY_TO_Q_MGR_VAL, \
    QUEUE_MANAGER_NAME_VAL, \
    QUEUE_NAME_VAL, \
    ALL_NUMBERS_VAL, \
    GETSQLCODE_PLUGIN_FACTORY_VAL, \
    '.', \
    ' '
#endif


/* finally, define the global initializer structure */
#if defined(GLOBAL_GETSQLCODE_DATA)
    getSQLCodeConstants_t C = {GETSQLCODE_CONSTANTS_DEFAULTS};
#else
    extern getSQLCodeConstants_t C;
#endif


#define GET_SQL_CODE_NODE_MB "GetSQLCodeNode"
#define ATTR_COPY_VALUE_TO_MB "CopyValueTo"


#define NULL_24 \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
#define NULL_48 \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
#define NULL_48_AND_TRAILING_NULL \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

#endif
